CXAppUtils class

Constructors

CXAppUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getAppName() Future<String?>
获取 app 名字
getBuildSignature() Future<String?>
获取App构建签名 在 iOS 上为空字符串,在 Android 上为密钥签名(十六进制)
getInstallerStore() Future<String?>
获取App安装商店 若是通过应用商店安装的应用,返回应用商店的名称,否则返回空字符串
getPackageName() Future<String?>
获取包名
getVersionName() Future<String?>
版本名
getVersionNumber() Future<String?>
版本号